@@ -15,15 +15,7 @@
 ;;; along with this program; if not, write to the Free Software
 ;;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-(provide 'vm-mouse)
-
-(defun vm-mouse-fsfemacs-mouse-p ()
-  (and vm-fsfemacs-p
-       (fboundp 'set-mouse-position)))
-
-(defun vm-mouse-xemacs-mouse-p ()
-  (and vm-xemacs-p
-       (fboundp 'set-mouse-position)))
+;;(provide 'vm-mouse)
 
 (defun vm-mouse-set-mouse-track-highlight (start end &optional overlay)
   (if (null overlay)
@@ -60,6 +52,10 @@
 	     nil
 	   (setq this-command 'vm-scroll-forward)
 	   (call-interactively 'vm-scroll-forward)))
+	((eq major-mode 'vm-folders-summary-mode)
+	 (mouse-set-point event)
+	 (beginning-of-line)
+	 (vm-follow-folders-summary-cursor))
 	((memq major-mode '(vm-mode vm-virtual-mode vm-presentation-mode))
 	 (vm-mouse-popup-or-select event))))
 
@@ -139,8 +135,7 @@
 	;; selectable objects are handled by an extent keymap
 	;; binding that points to a more specific function.  But
 	;; this might come in handy later if I want selectable
-	;; objects that don't have an extent or extent keymap
-	;; attached.
+	;; objects that don't have an extent keymap attached.
 	((vm-mouse-xemacs-mouse-p)
 	 (set-buffer (window-buffer (event-window event)))
 	 (and (event-point event) (goto-char (event-point event)))
@@ -186,15 +181,17 @@
 			  (overlay-end o)))
 	       (vm-mouse-send-url url browser)))))))
 
-(defun vm-mouse-send-url (url &optional browser)
+(defun vm-mouse-send-url (url &optional browser switches)
   (if (string-match "^mailto:" url)
       (vm-mail-to-mailto-url url)
-    (let ((browser (or browser vm-url-browser)))
+    (let ((browser (or browser vm-url-browser))
+	  (switches (or switches vm-url-browser-switches)))
       (cond ((symbolp browser)
 	     (funcall browser url))
 	    ((stringp browser)
 	     (message "Sending URL to %s..." browser)
-	     (vm-run-background-command browser url)
+	     (apply 'vm-run-background-command browser
+		    (append switches (list url)))
 	     (message "Sending URL to %s... done" browser))))))
 
 (defun vm-mouse-send-url-to-netscape (url &optional new-netscape new-window)
@@ -205,11 +202,12 @@
   (if new-netscape
       (apply 'vm-run-background-command vm-netscape-program
 	     (append vm-netscape-program-switches (list url)))
-    (or (equal 0 (apply 'vm-run-command vm-netscape-program "-remote" 
-			(append (list (concat "openURL(" url
-					      (if new-window ", new-window" "")
-					      ")"))
-				vm-netscape-program-switches)))
+    (or (equal 0 (apply 'vm-run-command vm-netscape-program
+			(append vm-netscape-program-switches
+				(list "-remote"
+				      (concat "openURL(" url
+					      (if new-window ",new-window" "")
+					      ")")))))
 	(vm-mouse-send-url-to-netscape url t new-window)))
   (message "Sending URL to Netscape... done"))
 
@@ -219,42 +217,96 @@
 (defvar buffer-file-type)
 
 (defun vm-mouse-send-url-to-mosaic (url &optional new-mosaic new-window)
-  (message "Sending URL to Mosaic...")
-  (if (null new-mosaic)
-      (let ((pid-file "~/.mosaicpid")
-	    (work-buffer " *mosaic work*")
-	    (coding-system-for-read 'no-conversion)
-	    (coding-system-for-write 'no-conversion)
-	    pid)
-	(cond ((file-exists-p pid-file)
-	       (set-buffer (get-buffer-create work-buffer))
-	       (erase-buffer)
-	       (insert-file-contents pid-file)
-	       (setq pid (int-to-string (string-to-int (buffer-string))))
-	       (erase-buffer)
-	       (insert (if new-window "newwin" "goto") ?\n)
-	       (insert url ?\n)
-	       ;; newline convention used should be the local
-	       ;; one, whatever that is.
-	       (setq buffer-file-type nil)
-	       (and vm-xemacs-mule-p
-		    (set-buffer-file-coding-system 'no-conversion nil))
-	       (write-region (point-min) (point-max)
-			     (concat "/tmp/Mosaic." pid)
-			     nil 0)
-	       (set-buffer-modified-p nil)
-	       (kill-buffer work-buffer)))
-	(cond ((or (null pid)
-		   (not (equal 0 (vm-run-command "kill" "-USR1" pid))))
-	       (setq new-mosaic t)))))
-  (if new-mosaic
-     (apply 'vm-run-background-command vm-mosaic-program
-	    (append vm-mosaic-program-switches (list url))))
-  (message "Sending URL to Mosaic... done"))
+  (vm-mouse-send-url-to-xxxx-mosaic 'mosaic url new-mosaic new-window))
+
+(defun vm-mouse-send-url-to-mmosaic (url &optional new-mosaic new-window)
+  (vm-mouse-send-url-to-xxxx-mosaic 'mmosaic url new-mosaic new-window))
+
+(defun vm-mouse-send-url-to-xxxx-mosaic (m-type url &optional
+					 new-mosaic new-window)
+  (let ((what (cond ((eq m-type 'mmosaic) "mMosaic")
+		    (t "Mosaic"))))
+    (message "Sending URL to %s..." what)
+    (if (null new-mosaic)
+	(let ((pid-file (cond ((eq m-type 'mmosaic)
+			       "~/.mMosaic/.mosaicpid")
+			      (t "~/.mosaicpid")))
+	      (work-buffer " *mosaic work*")
+	      (coding-system-for-read (vm-line-ending-coding-system))
+	      (coding-system-for-write (vm-line-ending-coding-system))
+	      pid)
+	  (cond ((file-exists-p pid-file)
+		 (set-buffer (get-buffer-create work-buffer))
+		 (setq selective-display nil)
+		 (erase-buffer)
+		 (insert-file-contents pid-file)
+		 (setq pid (int-to-string (string-to-int (buffer-string))))
+		 (erase-buffer)
+		 (insert (if new-window "newwin" "goto") ?\n)
+		 (insert url ?\n)
+		 ;; newline convention used should be the local
+		 ;; one, whatever that is.
+		 (setq buffer-file-type nil)
+		 (if (fboundp 'set-buffer-file-coding-system)
+		     (set-buffer-file-coding-system
+		      (vm-line-ending-coding-system) nil))
+		 (write-region (point-min) (point-max)
+			       (concat "/tmp/Mosaic." pid)
+			       nil 0)
+		 (set-buffer-modified-p nil)
+		 (kill-buffer work-buffer)))
+	  (cond ((or (null pid)
+		     (not (equal 0 (vm-run-command "kill" "-USR1" pid))))
+		 (setq new-mosaic t)))))
+    (if new-mosaic
+	(apply 'vm-run-background-command
+	       (cond ((eq m-type 'mmosaic) vm-mmosaic-program)
+		     (t vm-mosaic-program))
+	       (append (cond ((eq m-type 'mmosaic) vm-mmosaic-program-switches)
+			     (t vm-mosaic-program-switches))
+		       (list url))))
+    (message "Sending URL to %s... done" what)))
 
 (defun vm-mouse-send-url-to-mosaic-new-window (url)
   (vm-mouse-send-url-to-mosaic url nil t))
 
+(defun vm-mouse-send-url-to-konqueror (url &optional new-konqueror)
+  (message "Sending URL to Konqueror...")
+  (if new-konqueror
+      (apply 'vm-run-background-command vm-konqueror-program
+	     (append vm-konqueror-program-switches (list url)))
+    (or (equal 0 (apply 'vm-run-command vm-konqueror-client-program
+			(append vm-konqueror-client-program-switches
+				(list "openURL" url))))
+	(vm-mouse-send-url-to-konqueror url t)))
+  (message "Sending URL to Konqueror... done"))
+
+(defun vm-mouse-send-url-to-konqueror-new-browser (url)
+  (vm-mouse-send-url-to-konqueror url t))
+
+(defun vm-mouse-send-url-to-clipboard (url)
+  (message "Sending URL to X Clipboard...")
+  (cond ((fboundp 'own-selection)
+	 (own-selection url 'CLIPBOARD))
+	((fboundp 'x-own-clipboard)
+	 (x-own-clipboard url))
+	((fboundp 'x-own-selection-internal)
+	 (x-own-selection-internal 'CLIPBOARD url)))
+  (message "Sending URL to X Clipboard... done"))
+
+;; this code courtesy Thomas F. Burdick
+(defun vm-mouse-send-url-to-safari (url)
+  "Sends URL to Safari, using Apple's Open Scripting Architecture."
+  (message "Sending URL to Safari...")
+  (with-temp-buffer
+    (insert "tell application \"Safari\"\n")
+    (insert " activate\n")
+    (insert " make new document at the beginning of documents\n")
+    (insert (format " set the URL of the front document to \"%s\"\n" url))
+    (insert "end tell\n")
+    (call-process-region (point-min) (point-max) "/usr/bin/osascript"))
+  (message "Sending URL to Safari... done"))
+
 (defun vm-mouse-install-mouse ()
   (cond ((vm-mouse-xemacs-mouse-p)
 	 (if (null (lookup-key vm-mode-map 'button2))
@@ -278,9 +330,15 @@
 (defun vm-run-command-on-region (start end output-buffer command
 				       &rest arg-list)
   (let ((tempfile nil)
+	;; use binary coding system in FSF Emacs/MULE
+	(coding-system-for-read (vm-binary-coding-system))
+	(coding-system-for-write (vm-binary-coding-system))
 	;; for DOS/Windows command to tell it that its input is
 	;; binary.
 	(binary-process-input t)
+	;; call-process-region calls write-region.
+	;; don't let it do CR -> LF translation.
+	(selective-display nil)
 	status errstring)
     (unwind-protect
 	(progn
@@ -322,7 +380,7 @@
 HISTORY argument is ignored."
   (save-excursion
     (or dir (setq dir default-directory))
-    (set-buffer (generate-new-buffer " *Files*"))
+    (set-buffer (vm-make-work-buffer " *Files*"))
     (use-local-map (make-sparse-keymap))
     (setq buffer-read-only t
 	  default-directory dir)
@@ -422,7 +480,7 @@ HISTORY argument is ignored."
 
 (defun vm-mouse-read-string (prompt completion-list &optional multi-word)
   (save-excursion
-    (set-buffer (generate-new-buffer " *Choices*"))
+    (set-buffer (vm-make-work-buffer " *Choices*"))
     (use-local-map (make-sparse-keymap))
     (setq buffer-read-only t)
     (make-local-variable 'vm-mouse-read-string-prompt)
@@ -517,3 +575,5 @@ HISTORY argument is ignored."
   (if normal-exit
       (throw 'exit nil)
     (throw 'exit t)))
+
+(provide 'vm-mouse)
